# htsget

[![Travis](https://img.shields.io/travis/jeromekelleher/htsget/master.svg)](https://travis-ci.org/jeromekelleher/htsget) [![AppVeyor](https://ci.appveyor.com/api/projects/status/n68yw9qklvdham82/branch/master?svg=true)](https://ci.appveyor.com/project/jeromekelleher/htsget/branch/master) [![CodeCov](https://img.shields.io/codecov/c/github/jeromekelleher/htsget.svg)](https://codecov.io/gh/jeromekelleher/htsget) [![Read the docs](https://readthedocs.org/projects/htsget/badge/?version=latest)](http://htsget.readthedocs.io/en/latest/?badge=latest)

``htsget`` is a Python API and command line interface for the GA4GH Streaming API. It
provides a simple and reliable way to retrieve high-throughput sequencing data from
servers supporting the protocol.

Please see the [documentation](https://htsget.readthedocs.io/en/latest/) for more details.
